@@ -17,7 +17,7 @@ import matplotlib.pyplot as plt
 import matplotlib
 import numpy as np
 
-__version__ = '0.4.2'
+__version__ = '0.5.0'
 
 
 def system_has_latex():
@@ -196,6 +196,13 @@ See `this answer <https://stackoverflow.com/a/13490601/2646505>`__
     return float_str
 
 
+def minmax(a):
+    r'''
+Return [np.min(a), np.max(a)]
+    '''
+    return np.array([np.min(a), np.max(a)])
+
+
 def set_decade_lims(axis=None, direction=None):
     r'''
 Set limits the the floor/ceil values in terms of decades.
@@ -1124,11 +1131,11 @@ Determine bin-edges.
     **min_width** (``<float>``)
         The minimum width of each bin.
 
-    **integer** ([``False``] | [``True``])
+    **integer** ([``False``] | ``True``)
         If ``True``, bins not encompassing an integer are removed
         (e.g. a bin with edges ``[1.1, 1.9]`` is removed, but ``[0.9, 1.1]`` is not removed).
 
-    **remove_empty_edges** ([``True``] | [``False``])
+    **remove_empty_edges** ([``True``] | ``False``)
         Remove empty bins at the beginning or the end.
 
 :returns:
